@@ -73,10 +73,11 @@ class SpeechServer(speechserver.SpeechServer):
     DEFAULT_SERVER_ID = 'default'
     _SERVER_NAMES = {DEFAULT_SERVER_ID: guilabels.DEFAULT_SYNTHESIZER}
 
+    @staticmethod
     def getFactoryName():
         return guilabels.SPEECH_DISPATCHER
-    getFactoryName = staticmethod(getFactoryName)
 
+    @staticmethod
     def getSpeechServers():
         servers = []
         default = SpeechServer._getSpeechServer(SpeechServer.DEFAULT_SERVER_ID)
@@ -85,8 +86,8 @@ class SpeechServer(speechserver.SpeechServer):
             for module in default.list_output_modules():
                 servers.append(SpeechServer._getSpeechServer(module))
         return servers
-    getSpeechServers = staticmethod(getSpeechServers)
 
+    @classmethod
     def _getSpeechServer(cls, serverId):
         """Return an active server for given id.
 
@@ -99,20 +100,17 @@ class SpeechServer(speechserver.SpeechServer):
         # Don't return the instance, unless it is succesfully added
         # to `_active_Servers'.
         return cls._active_servers.get(serverId)
-    _getSpeechServer = classmethod(_getSpeechServer)
 
+    @staticmethod
     def getSpeechServer(info=None):
-        if info is not None:
-            thisId = info[1]
-        else:
-            thisId = SpeechServer.DEFAULT_SERVER_ID
+        thisId = info[1] if info is not None else SpeechServer.DEFAULT_SERVER_ID
         return SpeechServer._getSpeechServer(thisId)
-    getSpeechServer = staticmethod(getSpeechServer)
 
+    @staticmethod
     def shutdownActiveServers():
-        for server in list(SpeechServer._active_servers.values()):
+        servers = [s for s in SpeechServer._active_servers.values()]
+        for server in servers:
             server.shutdown()
-    shutdownActiveServers = staticmethod(shutdownActiveServers)
 
     # *** Instance methods ***
 
@@ -215,15 +213,29 @@ class SpeechServer(speechserver.SpeechServer):
         volume = int(15 * max(0, min(9, acss_volume)) - 35)
         self._send_command(self._client.set_volume, volume)
 
-    def _set_family(self, acss_family):
+    def _get_language_and_dialect(self, acss_family):
+        if acss_family is None:
+            acss_family = {}
+
         familyLocale = acss_family.get(speechserver.VoiceFamily.LOCALE)
         if not familyLocale:
             import locale
             familyLocale, encoding = locale.getdefaultlocale()
+
+        language, dialect = '', ''
         if familyLocale:
-            lang = familyLocale.split('_')[0]
-            if lang and len(lang) == 2:
-                self._send_command(self._client.set_language, str(lang))
+            localeValues = familyLocale.split('_')
+            language = localeValues[0]
+            if len(localeValues) == 2:
+                dialect = localeValues[1]
+
+        return language, dialect
+
+    def _set_family(self, acss_family):
+        lang, dialect = self._get_language_and_dialect(acss_family)
+        if len(lang) == 2:
+            self._send_command(self._client.set_language, lang)
+
         try:
             # This command is not available with older SD versions.
             set_synthesis_voice = self._client.set_synthesis_voice
@@ -231,8 +243,7 @@ class SpeechServer(speechserver.SpeechServer):
             pass
         else:
             name = acss_family.get(speechserver.VoiceFamily.NAME)
-            if name != self._default_voice_name:
-                self._send_command(set_synthesis_voice, name)
+            self._send_command(set_synthesis_voice, name)
 
     def _debug_sd_values(self, prefix=""):
         if debug.debugLevel > debug.LEVEL_INFO:
@@ -241,18 +252,25 @@ class SpeechServer(speechserver.SpeechServer):
         try:
             sd_rate = self._send_command(self._client.get_rate)
             sd_pitch = self._send_command(self._client.get_pitch)
+            sd_volume = self._send_command(self._client.get_volume)
+            sd_language = self._send_command(self._client.get_language)
         except:
-            sd_rate = "(exception occurred)"
-            sd_pitch = "(exception occurred)"
+            sd_rate = sd_pitch = sd_volume = sd_language = "(exception occurred)"
+
+        family = self._current_voice_properties.get(ACSS.FAMILY)
 
         current = self._current_voice_properties
-        msg = "SPEECH DISPATCHER: %sOrca rate %s, pitch %s; " \
-              "SD rate %s, pitch %s" % \
+        msg = "SPEECH DISPATCHER: %sOrca rate %s, pitch %s, volume %s, language %s; " \
+              "SD rate %s, pitch %s, volume %s, language %s" % \
               (prefix,
                self._current_voice_properties.get(ACSS.RATE),
                self._current_voice_properties.get(ACSS.AVERAGE_PITCH),
+               self._current_voice_properties.get(ACSS.GAIN),
+               self._get_language_and_dialect(family)[0],
                sd_rate,
-               sd_pitch)
+               sd_pitch,
+               sd_volume,
+               sd_language)
         debug.println(debug.LEVEL_INFO, msg, True)
 
     def _apply_acss(self, acss):
@@ -268,11 +286,13 @@ class SpeechServer(speechserver.SpeechServer):
             elif acss_property == ACSS.AVERAGE_PITCH:
                 method(5.0)
                 current[acss_property] = 5.0
-            elif acss_property == ACSS.FAMILY \
-                    and acss == settings.voices[settings.DEFAULT_VOICE]:
-                # We need to explicitly reset (at least) the family.
-                # See bgo#626072.
-                #
+            elif acss_property == ACSS.GAIN:
+                method(10)
+                current[acss_property] = 5.0
+            elif acss_property == ACSS.RATE:
+                method(50)
+                current[acss_property] = 5.0
+            elif acss_property == ACSS.FAMILY:
                 method({})
                 current[acss_property] = {}
 
@@ -400,7 +420,7 @@ class SpeechServer(speechserver.SpeechServer):
         try:
             volume = acss[ACSS.GAIN]
         except KeyError:
-            volume = 5
+            volume = 10
         acss[ACSS.GAIN] = max(0, min(9, volume + delta))
         msg = 'SPEECH DISPATCHER: Volume set to %d' % volume
         debug.println(debug.LEVEL_INFO, msg, True)
@@ -479,12 +499,7 @@ class SpeechServer(speechserver.SpeechServer):
                 utilities.adjustForPronunciation(name)
         self.speak(name, acss)
 
-    def speakKeyEvent(self, event):
-        if event.isPrintableKey() and event.event_string.isupper():
-            acss = settings.voices[settings.UPPERCASE_VOICE]
-        else:
-            acss = ACSS(settings.voices[settings.DEFAULT_VOICE])
-
+    def speakKeyEvent(self, event, acss=None):
         event_string = event.getKeyName()
         if orca_state.activeScript:
             event_string = orca_state.activeScript.\
